# -*- coding: utf-8 -*-
from setuphelpers import *

uninstallkey = []

# Declaring specific app values (TO CHANGE)
bin_name_x64 = 'vcredist_x64.exe'
bin_name_x86 = 'vcredist_x86.exe'
silent_args = '/q'
uninstall_key_x64 = '{1D8E6291-B0D5-35EC-8441-6616F567A0F7}'
uninstall_key_x86 = '{F0C3E5D1-1ADE-321E-8167-68EF0DE699A5}'
url_dl_x64 = 'http://download.microsoft.com/download/A/8/0/A80747C3-41BD-45DF-B505-E9710D2744E0/vcredist_x64.exe'
url_dl_x86 = 'http://download.microsoft.com/download/C/6/D/C6D0FD4E-9E53-4897-9B91-836EBA2AACD3/vcredist_x86.exe'
short_soft_name = 'Microsoft Visual C++ 2010'


def install():
    # Specific app values
    package_version = control.version.split('-')[0]
    app_name = control.name

    # Uninstalling older versions before install
    for uninstall in installed_softwares(short_soft_name):
        if Version(uninstall['version']) < Version(package_version):
            print('Older %s version found (%s)' % (app_name,uninstall['version']))
            print('Removing: %s (%s)' % (uninstall['name'],uninstall['version']))
            run(uninstall_cmd(uninstall['key']))

    # Installing the package
    install_exe_if_needed(bin_name_x86
        ,silentflags=silent_args
        ,key=uninstall_key_x86
        ,min_version=package_version)

    if iswin64():
        install_exe_if_needed(bin_name_x64
            ,silentflags=silent_args
            ,key=uninstall_key_x64
            ,min_version=package_version)


def update_package():
    print('Update/Download package content from upstream binary sources')

    # Getting proxy informations from WAPT settings
    proxy = {}
    if isfile(makepath(application_data(),'waptconsole','waptconsole.ini')):
        proxywapt = inifile_readstring(makepath(user_local_appdata(),'waptconsole','waptconsole.ini'),'global','http_proxy')
        if proxywapt :
            proxy = {'http':proxywapt,'https':proxywapt}

    # Downloading binaries
    if not isfile(bin_name_x64):
        print('Downloading ' + bin_name_x64)
        wget(url_dl_x64,bin_name_x64,proxies=proxy)

    if not isfile(bin_name_x86):
        print('Downloading ' + bin_name_x86)
        wget(url_dl_x86,bin_name_x86,proxies=proxy)

    version = Version(get_version_from_binary(bin_name_x86),3)

    # Changing version of the package
    control.version = '%s-%s'%(version,int(control.version.split('-')[-1])+1)
    control.save_control_to_wapt()
    print('Changing package version to: %s in WAPT\\control' % control.version)


def get_version_from_binary(filename):
    if filename.endswith('.msi'):
        return get_msi_properties(filename)['ProductVersion']
    else:
        return get_file_properties(filename)['ProductVersion']

